pub struct ListSegmentsRequest {
pub src_isd_as: u64,
pub dst_isd_as: u64,
pub page_size: i32,
pub page_token: String,
}Expand description
List segments request.
Fields
src_isd_as: u64The source ISD-AS of the final end-to-end path. This is most likely the requester’s own ISD-AS.
dst_isd_as: u64The destination ISD-AS the final end-to-end path.
page_size: i32The maximum total number of segments to return. The service may return fewer than this value. If unspecified, the maximum number of segments per page is returned, which is 64.
page_token: StringA page token, received from a previous ListSegmentsRequest call. Provide this to retrieve the subsequent page.
When paginating, all other parameters provided in ListSegmentsRequest must match the call that provided the page token.