pub struct ListUnderlaysRequest {
pub isd_as: Option<u64>,
}Expand description
ListUnderlaysRequest is used to discover available transport underlays.
Fields
isd_as: Option<u64>Include the underlays for the provided ISD-AS. This can be left empty or set to 0 which indicates that the requester wants the underlay information for all possible local SCION ASes.
Implementations